//#####################################################################
// Copyright 2022
// This file is part of PhysBAM whose distribution is governed by the license contained in the accompanying file PHYSBAM_COPYRIGHT.txt.
//#####################################################################
#include <Core/Log/LOG.h>
#include <Core/Matrices/MATRIX.h>
#include <Core/Ordinary_Differential_Equations/RUNGEKUTTA.h>
#include <Core/Symbolics/EXECUTABLE_PROGRAM.h>
#include <Core/Symbolics/PROGRAM_COMPILER.h>
#include <Core/Symbolics/PROGRAM_SCALAR.h>
#include "CHNS_SYMBOLIC.h"

namespace PhysBAM{

//#####################################################################
// Constructor
//#####################################################################
template<class TV> CHNS_SYMBOLIC<TV>::
CHNS_SYMBOLIC()
{
}
//#####################################################################
// Destructor
//#####################################################################
template<class TV> CHNS_SYMBOLIC<TV>::
~CHNS_SYMBOLIC()
{
    for(auto&i:t_map) delete i.second;
    for(auto&i:tv_map) delete i.second;
}
//#####################################################################
// Function Get_T
//#####################################################################
template<class TV> auto CHNS_SYMBOLIC<TV>::
Get_T(std::string key,const TV& X) const -> T
{
    inputs.Subset(idx_X)=X/distance_scale;
    return t_map.Get(key)->Eval(inputs);
}
//#####################################################################
// Function Get_TV
//#####################################################################
template<class TV> TV CHNS_SYMBOLIC<TV>::
Get_TV(std::string key,const TV& X) const
{
    inputs.Subset(idx_X)=X/distance_scale;
    return tv_map.Get(key)->Eval(inputs);
}
//#####################################################################
// Function Get_Mat
//#####################################################################
// template<class TV> auto CHNS_SYMBOLIC<TV>::
// Get_Mat(std::string key,const TV& X) const -> MATRIX<T,TV::m,TV::m>
// {
//     for(int i=0;i<TV::m;i++) inputs(i)=X(i);
//     return mat_map.Get(key)->Eval(inputs);
// }
template class CHNS_SYMBOLIC<VECTOR<float,2> >;
template class CHNS_SYMBOLIC<VECTOR<double,2> >;
template class CHNS_SYMBOLIC<VECTOR<float,3> >;
template class CHNS_SYMBOLIC<VECTOR<double,3> >;
}
