//#####################################################################
// Copyright 2024.
// This file is part of PhysBAM whose distribution is governed by the license contained in the accompanying file PHYSBAM_COPYRIGHT.txt.
//#####################################################################
// Class CHN_OBJECTIVE
//#####################################################################
#ifndef __CHN_OBJECTIVE__
#define __CHN_OBJECTIVE__
#include <Core/Arrays/ARRAY.h>
#include <Core/Krylov_Solvers/KRYLOV_SYSTEM_BASE.h>
#include <Core/Krylov_Solvers/KRYLOV_VECTOR_BASE.h>
#include <Core/Krylov_Solvers/MATRIX_SYSTEM.h>
#include <Core/Matrices/SPARSE_MATRIX_FLAT_MXN.h>
#include <Core/Nonlinear_Equations/NONLINEAR_FUNCTION.h>
#include <Core/Vectors/VECTOR.h>
namespace PhysBAM{

template<class TV>
class CHN_OBJECTIVE:public NONLINEAR_FUNCTION<typename TV::SCALAR(KRYLOV_VECTOR_BASE<typename TV::SCALAR>&)>
{
    typedef typename TV::SCALAR T;
    mutable KRYLOV_VECTOR_WRAPPER<T,ARRAY<T> > temp;
    mutable SPARSE_MATRIX_FLAT_MXN<T> mod_L;
    bool enforce_compatibility=false;
    T r=0.01;
    T k=0.1;
    bool alt_F=false;
    bool linearized=false;
public:
    SPARSE_MATRIX_FLAT_MXN<T> L;
    MATRIX_SYSTEM<SPARSE_MATRIX_FLAT_MXN<T>,T,KRYLOV_VECTOR_WRAPPER<T,ARRAY<T>>> system;
    ARRAY<T> b;
    bool use_preconditioner=true;

    void Test_g() const;
    T g(T x) const;
    T dg(T x) const;
    T ddg(T x) const;
        
    CHN_OBJECTIVE(SPARSE_MATRIX_FLAT_MXN<T>& L_in,const ARRAY<T> &b_in,T k_in,T r_in,bool enforce_compatibility,bool altF,bool linear);
    virtual ~CHN_OBJECTIVE();
    
    void Compute(const KRYLOV_VECTOR_BASE<T>& x_in,KRYLOV_SYSTEM_BASE<T>* hess,KRYLOV_VECTOR_BASE<T>* grad,T* e) const override;
};
}
#endif
