//#####################################################################
// Copyright 2022
// This file is part of PhysBAM whose distribution is governed by the license contained in the accompanying file PHYSBAM_COPYRIGHT.txt.
//#####################################################################
#ifndef __CH_SYMBOLIC__
#define __CH_SYMBOLIC__
#include <Core/Data_Structures/HASHTABLE.h>
#include <Core/Symbolics/INSTRUCTION.h>
#include <Core/Vectors/VECTOR.h>
#include <cfloat>
namespace PhysBAM{

template<class T> class EXECUTABLE_PROGRAM;
namespace NS_PROGRAM_SCALAR{template<class T> class PROGRAM_SCALAR;}

template<class TV>
class CH_SYMBOLIC
{
    typedef typename TV::SCALAR T;
    typedef VECTOR<int,TV::m> IV;
    
protected:
    HASHTABLE<std::string,EXECUTABLE_PROGRAM<T>*> t_map;
    HASHTABLE<std::string,EXECUTABLE_PROGRAM<TV>*> tv_map;
    // HASHTABLE<std::string,EXECUTABLE_PROGRAM<MATRIX<T,TV::m,TV::m> >*> mat_map;
    mutable ARRAY<T,MEM_IN> inputs;
    VECTOR<MEM_IN,TV::m> idx_X;
    MEM_IN idx_t;
    MEM_IN idx_dt;
    MEM_IN idx_lambda;
    MEM_IN idx_eta;
    MEM_IN idx_M;
    MEM_IN idx_second_order;
    MEM_IN idx_t2;
    MEM_IN idx_t0;
    MEM_IN idx_sigma;
    MEM_IN idx_m;
    MEM_IN idx_s;
    MEM_IN idx_kg;
    MEM_IN idx_speed_scale;
    MEM_IN input_size;

    VECTOR<MEM_OUT,TV::m> idx_u;
    MEM_OUT idx_p;
    MEM_OUT idx_gamma;
public:
    T lambda = FLT_MAX;
    T eta = FLT_MAX;
    T M = FLT_MAX;
    T second_order = FLT_MAX;
    T sigma = FLT_MAX;
    T distance_scale=1;
    T time_scale=1;
    T mass_scale=1;
    T speed_scale=1;
   
    CH_SYMBOLIC();
    virtual ~CH_SYMBOLIC();
    
    virtual void Set_Step(T time, T dt)=0;
    
    T Get_T(std::string key,const TV& X) const;
    TV Get_TV(std::string key,const TV& X) const;
    // MATRIX<T,TV::m,TV::m> Get_Mat(std::string key,const TV& X) const;
};
}
#endif
