#!/bin/bash
#===================================================================
# August 2023 -Mehrnaz Ayazi, Jason Goulding
# Creates plots of pressure versus x/y
# Uses the end-state frames of the steady_drop.sh, case 1
#===================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

(
    function f()
    {
        type=$1
        dir=$2
        min=$3
        max=$4

        IFS='_-' read -a RES <<< $dir
       echo ${RES[2]}
        CASE=${RES[2]}
         echo "case=$CASE"

        inputfile="st_"$type"_"$dir".txt"
        outputfile="$fig/tex/surface_tension_"$type"_"$CASE".tex"
        echo "outputfile=$outputfile"
        plotfile="$fig/tex/st_"$type"_graph_"$CASE".tex"
        cp $sc/st_magnitude.tex $outputfile
        sed -i -e "s@FIG@$fig@g" -e  "s|GRAPHNAME|$plotfile|g" $outputfile

        (gnuplot -c $sc/st_"$type".gp $fig/txt/$inputfile $plotfile $min $max)  &&(sed -i -e "s@FIG@$fig@g" -e 's/\\definecolor{tbcol}{rgb}{1,1,1}%//g'  $plotfile)&& (pdflatex -halt-on-error -output-format=pdf -output-directory=$fig/pdfs --shell-escape $outputfile)&&(pdfcrop "$fig/pdfs/surface_tension_${type}_${CASE}.pdf" "$fig/pdfs/surface_tension_${type}_${CASE}_cropped.pdf")&& (cp $fig/pdfs/surface_tension_"$type"_"$CASE"_cropped.pdf $fig) &
    }

    for CASE in 1 2 3 4 5 6 7 8 9;
        do
#            directory="pressure_"$CASE
            directory="surface_tension_"$CASE
            $basedir/surface_tension -fig $fig -dir $directory -frame 25 -threshold "1e-10"

            f 'mag' $directory 0 100
            f 'angle' $directory 0 1
        done

        wait
)

