#! /usr/bin/env bash
#=================================================================
# Usage: constant_b_test.sh <fig> 
#=================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

end_frame=${1:-1}
option=$2
code_in=$3
sigma=0.00942809 # chosen such that lambda=1e-3
dt=0.01
refine=16
use_out="-suppress_output"

CMD="$basedir/chns -test 1 -ch_M 0.001 -ch_sigma $sigma -rho0 1 -rho1 3 -mu0 0.01 -mu1 0.02 -ch_eta 0.1 -source_sym -test_sym -second_order $use_out -ch_h_tol 1e-15 -p_tol 1e-15 -mu_tol 1e-15 -st_type 5 -div_free -ch_optimizer -ch_min 0.1 -res 8 -refine $refine -frame_dt $dt -spf 1 -e $end_frame $option"

if [ -z "$code_in" ]
then
    CODE="gamma=1/2+cos(x)*cos(y)*(1-sin(t))/2.1;u=sin(x)*cos(y)*cos(t);v=-cos(x)*sin(y)*cos(t);p=cos(x)*cos(y)*sin(t);"
#    CODE="gamma=1/2+cos(x)*cos(y)*(1-sin(t))/2.1;u=0;v=0;p=0;"
else
    CODE="$code_in"
fi
directory=$fig/"b_nonperiodic_test_"$end_frame"_opt"

mkdir $directory
echo "testing b constant (pi range)"
for b in 1e-6 1e-5 1e-4 1e-3 1e-2 1e-1 0.11 0.12 0.13 0.14 0.15; do
(
    echo $CMD -gravity_v "\"1 -2\"" -o $fig/constant_b_outputs/test_"$b" -code "\"""$CODE""\"" -ch_b "$b"
    output=$( $CMD -gravity_v "1 -2" -o $fig/constant_b_outputs/test_"$b" -code "$CODE" -ch_b "$b")
    echo "${output}" | grep "gamma2" | tail -n 1 > $directory/log_"$b".txt  
    echo "${output}" | grep "q=" | tail -n 1 > $directory/log_"$b"_q.txt  
)&
done
wait

# output table for figure generation
rm $fig/b_error_table.txt
echo "q b l2err linferr" >> $fig/b_error_table.txt
for b in 1e-6 1e-5 1e-4 1e-3 1e-2 1e-1 0.11 0.12 0.13 0.14 0.15; do
    q=$(cat $directory/log_"$b"_q.txt | awk -F"[_=]" '{print $2}')
    l2err=$(cat $directory/log_"$b".txt | awk '{print $8}')
    linferr=$(cat $directory/log_"$b".txt | awk '{print $12}')
    echo $directory/log_"$b".txt
    echo "$b" "$q" "$l2err" "$linferr"
    echo "$b" "$q" "$l2err" "$linferr"  >> $fig/b_error_table.txt
done
echo logging table to $fig/b_error_table.txt

