#! /usr/bin/env bash
#==========================================================
# Horizontal Shear test suite
# Usage: horizontal_shear.sh <fig> [test number=1] [cahn hilliard type=0] [optional argument=none]
#==========================================================
# TEST #      rho1      rho0    Mu1     Mu0      sigma
#   1         1         1       0       0        1e-12
#   2         10        1       0       0        1e-12
#   3         1         1       1e-2    1e-3     1e-12
#   4         10        1       1e-2    1e-3     1e-12
#   5         1         1       0       0        0.1
#   6         10        1       0       0        0.1
#==========================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-1}
ch_type=${2:0}
option=$3

CMD="$basedir/chns -test 21 -second_order -st_type 2 -ch_h_tol 1e-15 -mu_tol 1e-15 -p_tol 1e-15 "

if [ $ch_type -eq 0 ]
then
    CMD="$CMD -ch_unbounded "
else
    CMD="$CMD -ch_optimizer -ch_n_tol 1e-15 "
fi

res=128
eta=$(perl -e 'print 1/(30*sqrt(2))')
M="1e-7"
dt=0.01
end_frame=100
spf=20
refine=1

sigma="1e-12"
mu0=0
mu1=0
rho0=1
rho1=1

if [ $test -eq 2 ]
then
    sigma="1e-12"
    mu0=0
    mu1=0
    rho0=1
    rho1=10
elif [ $test -eq 3 ]
then
    sigma="1e-12"
    mu0=0.001
    mu1=0.01
    rho0=1
    rho1=1
elif [ $test -eq 4 ]
then
    sigma="1e-12"
    mu0=0.001
    mu1=0.01
    rho0=1
    rho1=10
elif [ $test -eq 5 ]
then
    sigma=0.1
    mu0=0
    mu1=0
    rho0=1
    rho1=1
elif [ $test -eq 6 ]
then
    sigma=0.1
    mu0=0
    mu1=0
    rho0=1
    rho1=10
elif [ $test -eq 7 ] # larger M and sigma
then
    sigma=1
    M="1e-5"
    mu0=0
    mu1=0
    rho0=1
    rho1=1
    option="$option -no_st_force "
    # no st force?
elif [ $test -eq 8 ] # refine 2
then
    refine=2
elif [ $test -eq 9 ] # refine 4
then
    refine=4
elif [ $test -eq 10 ] # weno advection for momentum
then
    option="$option -old_adv "
fi

echo  $CMD -mu0 $mu0 -mu1 $mu1 -ch_sigma $sigma -ch_M $M -ch_eta $eta -rho0 $rho0 -rho1 $rho1 -frame_dt $dt -e $end_frame -range_max "1 1" -res $res -refine $refine -spf $spf -o $fig/horizontal_shear_$test $option &
$CMD -mu0 $mu0 -mu1 $mu1 -ch_sigma $sigma -ch_M $M -ch_eta $eta -rho0 $rho0 -rho1 $rho1 -frame_dt $dt -e $end_frame -range_max "1 1" -res $res -refine $refine -spf $spf -o $fig/horizontal_shear_$test $option >/dev/null &

wait
