#! /usr/bin/env bash
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-0}
end_frame=1
dt=0.1
option=$2
use_out=$3
len=22
M=0.001
sigma=0.00942809
eta=0.1
types=('gamma2' 'p2' 'u2_x' 'u2_y')

if [ "X$use_out" = "X1" ] ; then
    use_out="-substeps 1 -error_output"
else
    use_out="-suppress_output"
fi

rm -f $fig/tmp-*txt

CMD="$basedir/chns -test 1 -M $M -sigma $sigma -rho0 3 -rho1 1 -eta $eta -source_sym -test_sym -linear $use_out $option"

if [ $test -eq 0 ]
then
    CODE="k1=2*pi;k0=k1^2*M*lambda*(k1^2*eta^2+1)/eta^2;gamma=exp(-k0*t)*cos(k1*x);u=0;v=0;p=0;"
    echo "testing linear solution: refinement"
    for i in 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20; do
        echo $CMD -res 8 -frame_dt $dt -refine $i -spf 1 -e $end_frame -range_scale "0 1" -o $fig/source_outputs/linear"$test"_$i -code "$CODE"
        ( $CMD -res 8 -frame_dt $dt -refine $i -spf 1 -e $end_frame -range_scale "0 1" -o $fig/source_outputs/linear"$test"_$i -code "$CODE" | grep L2 | tail -n $len > $fig/log-$test-$i.txt) &
    done
    wait

    middle_output="linear_intermediate.txt"
    rm $fig/$middle_output
    for i in $fig/log-$test-*.txt ; do
        echo ==== $i ==== >> $fig/$middle_output
        cat $i >> $fig/$middle_output
    done

    rm $fig/*_order.txt
    for type in ${types[*]} ; do
        (grep -F "($type)" $fig/$middle_output | awk '{print $2 " " $8 " " $12}' > $fig/"$type"_summary.txt && $ex/convergence_order.py $fig/"$type"_summary.txt > $fig/"$type"_order.txt) &
    done
    wait

    final_output="linear_summary.txt"
    rm $fig/$final_output
    for type in ${types[*]} ; do
        echo ==== $type ==== >> $fig/$final_output
        cat $fig/"$type"_order.txt >> $fig/$final_output
    done
    #rm $fig/*_order.txt
elif [ $test -eq 1 ]
then
    CODE="k1=2*pi;k0=1;gamma=exp(-k0*t)*cos(k1*x);u=0;v=0;p=0;"
    echo "testing linear solution: refinement"
    for i in 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20; do
        echo $CMD -res 8 -frame_dt $dt -refine $i -spf 1 -e $end_frame -range_scale "0 1" -o $fig/source_outputs/linear"$test"_$i -code "$CODE"
        ( $CMD -res 8 -frame_dt $dt -refine $i -spf 1 -e $end_frame -range_scale "0 1" -o $fig/source_outputs/linear"$test"_$i -code "$CODE" | grep L2 | tail -n $len > $fig/log-$test-$i.txt) &
    done
    wait

    middle_output="linear_intermediate.txt"
    rm $fig/$middle_output
    for i in $fig/log-$test-*.txt ; do
        echo ==== $i ==== >> $fig/$middle_output
        cat $i >> $fig/$middle_output
    done

    rm $fig/*_order.txt
    for type in ${types[*]} ; do
        (grep -F "($type)" $fig/$middle_output | awk '{print $2 " " $8 " " $12}' > $fig/"$type"_summary.txt && $ex/convergence_order.py $fig/"$type"_summary.txt > $fig/"$type"_order.txt) &
    done
    wait

    final_output="linear_summary.txt"
    rm $fig/$final_output
    for type in ${types[*]} ; do
        echo ==== $type ==== >> $fig/$final_output
        cat $fig/"$type"_order.txt >> $fig/$final_output
    done
    #rm $fig/*_order.txt
fi

wait
