#! /usr/bin/env bash
#=================================================================
# Tests the accuracy of manufactured solution with slip boundaries
# Outputs convergence order of gamma,velocity and pressure to a directory(refine_nonperiodic_test_$end_frame)
# Calculates L2 and L_inf norms for error of the above
# Usage: paper_tests_non_periodic_ch.sh <fig> [test number=1] [end frame=100] [optional argument=none]
#=================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

#for i in 010 020 030 040 050 060 070 080 090 100 157 200 300 314 400 471 500 600 628 ; do $ex/paper_tests_non_periodic.sh $fig 1 $i & done

test=${1:-1}
end_frame=${2:-100}
option=$3
code_in=$4
use_out="no"
len=37
sigma=0.00942809 # chosen such that lambda=1e-3
dt=0.01
types=('gamma2')

if [ "X$use_out" = "X1" ] ; then
    use_out="-substeps 1 -error_output"
else
    use_out="-suppress_output"
fi

rm -f $fig/tmp-*txt
directory=$fig/nonperiodic_ch_"$test"_"$end_frame"
ref_directory=$fig/refine_nonperiodic_ch_"$test"_"$end_frame"

CMD="$basedir/chns -test 1 -res 8 -frame_dt $dt -spf 1 -e $end_frame -ch_M 0.001 -ch_sigma $sigma -rho0 1 -rho1 3 -mu0 0 -mu1 0 -ch_eta 0.1 -source_sym -test_sym -second_order $use_out -ch_h_tol 1e-15 -mu_tol 1e-15 -p_tol 1e-15 -no_adv -no_st_force -no_viscosity -st_type 5 -div_free "

if [ $test -eq 0 ] # ch_optimizer test
then
    if [ -z "$code_in" ]
    then
        CODE="gamma=1/2+cos(x)*cos(y)*(1-sin(t))/2.1;u=0;v=0;p=0;"
    else
        CODE="$code_in"
    fi
    CMD="$CMD -ch_optimizer -ch_min 0.1 "
    directory=$ref_directory"_opt"
elif [ $test -eq 1 ]
then
    if [ -z "$code_in" ]
    then
        CODE="gamma=(cos(x)*cos(y)+1)/2*sin(t);u=0;v=0;p=0;"
    else
        CODE="$code_in"
    fi
    directory=$ref_directory
elif [ $test -eq 2 ] # ch_optimizer test
then
    if [ -z "$code_in" ]
    then
        CODE="gamma=1/2+cos(x)*cos(y)*(1-sin(t))/2.1;u=0;v=0;p=0;"
    else
        CODE="$code_in"
    fi
    CMD="$CMD -ch_optimizer -ch_min 0.05 "
    directory=$ref_directory"_opt"
elif [ $test -eq 3 ] # ch_optimizer test
then
    if [ -z "$code_in" ]
    then
        CODE="gamma=1/2+cos(x)*cos(y)*(1-sin(t))/2.1;u=0;v=0;p=0;"
    else
        CODE="$code_in"
    fi
    CMD="$CMD -ch_optimizer -ch_min 0.01 "
    directory=$ref_directory"_opt"
fi

CMD="$CMD $option"

mkdir $directory
echo "testing paper solution (pi range)"
for i in 01 02 04 08 16 32 64; do
# for i in 01 02 04 08 16 32; do
    echo $CMD -refine $i -gravity_v "0 0" -o $fig/source_outputs/test"$test"_$i -code "$CODE"
    ( $CMD -refine $i -gravity_v "0 0" -o $fig/source_outputs/test"$test"_$i -code "$CODE" | grep L2 | tail -n $len > $directory/log-$test-$i.txt) >/dev/null &
done
wait
middle_output="$directory/total_intermediate.txt"
rm $middle_output
for i in $directory/log-$test-*.txt ; do
    echo ==== $i ==== >> $middle_output
    cat $i >> $middle_output
done

rm $directory/*_order.txt
for type in ${types[*]} ; do
    (grep -F "($type)" $middle_output | awk '{print $2 " " $8 " " $12}' > $directory/"$type"_summary.txt && $ex/convergence_order.py $directory/"$type"_summary.txt > $directory/"$type"_order.txt) >/dev/null &
done
wait

rm $directory/table.tex
TABLE_CMD="$ex/generate_table_ch.py"
for type in ${types[*]} ; do
    TABLE_CMD="$TABLE_CMD $directory/"$type"_summary.txt"
done
$TABLE_CMD > $directory/table.tex && cp $directory/table.tex $fig
wait

final_output="$directory/total_summary.txt"
rm $final_output
for type in ${types[*]} ; do
    echo ==== $type ==== >> $final_output
    cat $directory/"$type"_order.txt >> $final_output
done
#rm $fig/*_order.txt

wait
