#! /usr/bin/env bash
#========================================================
# Tests momentum conservation with periodic advection
# Usage: periodic_advection_test.sh <fig> [test number=0] [cahn hilliard type=0] [optional argument=none]
#========================================================
# TEST #     rho0      rho1     sigma
#   0        1         1        1e-12
#   1        1         1e3      1e-12
#   2        1         1e6      1e-12
#   3        1         1e9      1e-12
#   4        1         1        1
#   5        1         1e3      1
#   6        1         1e6      1
#   7        1         1e9      1
#for test 4 to run either change rho0/rho1 to 1000/1000 or change dt=0.000078125
#========================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-0}
ch_type=${2:-0}
# end_frame=1280
# steps=1
# dt=0.00078125
end_frame=64
steps=20
dt=0.015625
option=$3
M="1e-7"
eta=0.0234375 #3*1/res

CMD="$basedir/chns -test 15 -res 128 -frame_dt $dt -e $end_frame -ch_M $M -ch_eta $eta $option -second_order -periodic -st_type 2 -mu0 0 -mu1 0 -spf $steps -ch_h_tol 1e-12 -mu_tol 1e-12 -p_tol 1e-12 "

if [ $ch_type -eq 1 ]
then
    CMD="$CMD -ch_optimizer "
fi

# density ratio 1
if [ $test -eq 0 ]
then
    sigma="1e-12"
    rho0="1"
    rho1="1"
    bound=""
# density ratio 1e3
elif [ $test -eq 1 ]
then
    sigma="1e-12"
    rho0="1"
    rho1="1e3"
    bound=""
    if [ $ch_type -eq 1 ]
    then
        CMD="$CMD "
    fi
# density ratio 1e6
elif [ $test -eq 2 ]
then
    sigma="1e-12"
    rho0="1"
    rho1="1e6"
    bound=""
    if [ $ch_type -eq 1 ]
    then
        CMD="$CMD "
    fi
# density ratio 1e9
elif [ $test -eq 3 ]
then
    sigma="1e-12"
    rho0="1"
    rho1="1e9"
    if [ $ch_type -eq 0 ]
    then
        bound="-ch_bound_limit 1e-10"
    else
        bound=""
        CMD="$CMD "
    fi
    wait
# sigma 1, density ratio 1
elif [ $test -eq 4 ]
then
    sigma="1"
    rho0="1e3"
    rho1="1e3"
    bound=""
# sigma 1, density ratio 1e3
elif [ $test -eq 5 ]
then
    sigma="1"
    rho0="1e3"
    rho1="1e6"
    bound=""
    if [ $ch_type -eq 1 ]
    then
        CMD="$CMD "
    fi
# sigma 1, density ratio 1e6
elif [ $test -eq 6 ]
then
    sigma="1"
    rho0="1e3"
    rho1="1e9"
    bound=""
    if [ $ch_type -eq 1 ]
    then
        CMD="$CMD "
    fi
# sigma 1, density ratio 1e9
elif [ $test -eq 7 ]
then
    sigma="1"
    rho0="1e3"
    rho1="1e12"
    if [ $ch_type -eq 0 ]
    then
        bound="-ch_bound_limit 1e-9"
    else
        bound=""
        CMD="$CMD "
    fi
fi
echo  $CMD -ch_sigma $sigma -rho0 $rho0 -rho1 $rho1 -range_scale "0 1" -o $fig/periodic_advection_$test $bound &
( $CMD -ch_sigma $sigma -rho0 $rho0 -rho1 $rho1 -range_scale "0 1" -o $fig/periodic_advection_$test $bound ) >/dev/null &

wait
