#! /usr/bin/env bash
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-0}
end_frame=1
dt=0.01
option=$2
use_out="no"
len=37
M=0.001
sigma=0.00942809
eta=0.1
types=('gamma2' 'p2' 'u2_x' 'u2_y')

if [ "X$use_out" = "X1" ] ; then
    use_out="-substeps 1 -error_output"
else
    use_out="-suppress_output"
fi

CMD="$basedir/chns -test 1 -e $end_frame -res 8 -frame_dt $dt -M $M -sigma $sigma -rho0 1 -rho1 3 -eta $eta -source_sym -test_sym $use_out $option -tol 1e-15 -periodic -st_type 5 -mu0 0.02 -mu1 0.01 "
#CODE="u=-sin(x)*cos(y)*exp(-t);v=cos(x)*sin(y)*exp(-t);p=rho1*sin(x)*sin(y)*exp(-(t+dt));"
#CODE="u=sin(x)*cos(y);v=-cos(x)*sin(y);p=cos(x)*cos(y);"
CODE="u=sin(x)*cos(y)*cos(t);v=-cos(x)*sin(y)*cos(t);p=cos(x)*cos(y)*sin(t);"
EXTRA=""
# 0: gamma=1, ch, advection, surface tension (should be effectively 0)
# 1: gamma=0.25, no ch, advection, no surface tension
# 2: gamma sin(t), ch, advection, no surface tension
# 3: gamma cos(x)cos(y), no ch, advection, no surface tension
# 4: gamma=1, ch, no advection, surface tension (should be effectively 0)
# 5: gamma=0.25, no ch, no advection, no surface tension
# 6: gamma sin(t), ch, no advection, no surface tension
# 7: gamma cos(x)cos(y), no ch, no advection, no surface tension
[ $(($test & 3)) = 0 ] && CODE="$CODE"'gamma=(cos(x)*cos(y)+1)/2*sin(t);'
[ $(($test & 3)) = 1 ] && CODE="$CODE"'gamma=0.25;'
[ $(($test & 3)) = 2 ] && CODE="$CODE"'gamma=(cos(x)*cos(y)+1)/2*sin(t);'
[ $(($test & 3)) = 3 ] && CODE="$CODE"'gamma=(cos(x)*cos(y)+1)/2;'

[ $(($test & 1)) = 1 ] && EXTRA="$EXTRA -no_ch -no_st_force"
[ $(($test & 4)) = 4 ] && EXTRA="$EXTRA -no_adv -no_st_force"
[ $(($test & 3)) = 0 ] && EXTRA="$EXTRA"
# [ $(($test & 3)) = 0 ] && EXTRA="$EXTRA -no_ch"

directory=$fig/pressure_test_$test
mkdir $directory

for i in 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20; do
    echo $CMD -refine $i -range_scale "3.14159265359 3.14159265359" -o $fig/source_outputs/test"$test"_$i $EXTRA -code "$CODE"
    ( $CMD -refine $i -range_scale "3.14159265359 3.14159265359" -o $fig/source_outputs/test"$test"_$i $EXTRA -code "$CODE" | grep L2 | tail -n $len > $directory/log-$test-$i.txt) >/dev/null &
done
wait
middle_output="$directory/total_intermediate.txt"
rm $middle_output
for i in $directory/log-$test-*.txt ; do
    echo ==== $i ==== >> $middle_output
    cat $i >> $middle_output
done

rm -f $directory/*-order.txt
for type in ${types[*]} ; do
    (grep -F "($type)" $middle_output | awk '{print $2 " " $8 " " $12}' > $directory/"$type"_summary.txt && $ex/convergence_order.py $directory/"$type"_summary.txt > $directory/"$type"_order.txt) >/dev/null &
done
wait

final_output="$directory/total_summary.txt"
rm $final_output
for type in ${types[*]} ; do
    echo ==== $type ==== >> $final_output
    cat $directory/"$type"_order.txt >> $final_output
done
