#! /usr/bin/env bash
#===================================================================
# Tests stability of optimizer by simulating phase separation purely due to Cahn-Hilliard
# Runs at multiple refinement levels for multiple values of q
# Usage: stability_test_q.sh <fig> [optional argument=none]
#===================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

option=$1

res=16
# periodic
# ML=eta^2
# eta^2=0.001?
eta=0.03162277660
M=0.02981423968
sigma=1
# random values between 0.475 and 0.525
randomscale=0.05
dt=0.0032
endtime=500
spf=1
CMD="$basedir/chns -test 0 -random_gamma $randomscale -second_order -e $endtime -frame_dt $dt -res $res -ch_sigma $sigma -ch_eta $eta -ch_M $M -rho0 1 -rho1 1 -mu0 0 -mu1 0 $option -no_adv -no_st_force -no_viscosity -spf $spf -mu_tol 1e-12 -p_tol 1e-12 -ch_h_tol 1e-12 "

mkdir -p $fig/stability_logs

for refine in 1 2 4 8 16 32;
do
    for qrefine in 1 2 4 8 16 32 64 128 256 512;
    do
        ref_string=$(printf "%02d" $refine)
        q_string=$(printf "%03d" $qrefine)
        q=$(perl -e 'print 1/2/'$qrefine)
        echo $CMD -refine $refine -ch_optimizer -ch_q $q -periodic -range_scale '"0 6.283185308"' -o $fig/stability_"$ref_string"_"$q_string"
        $CMD -refine $refine -ch_optimizer -ch_q $q -periodic -range_scale "0 6.283185308" -o $fig/stability_"$ref_string"_"$q_string" >/dev/null 2>$fig/stability_logs/error_"$ref_string"_"$q_string".txt &
    done
done

wait    
