#! /usr/bin/env bash
#========================================================
# Steady Drop test suite
# Usage: steady_drop.sh <fig> [case number=0] [optional argument=none]

# TEST #    rho1      rho0      Mu1     Mu0     sigma
#   0       1000      1000      0       0       1e-12
#   1       1000      1000      0       0       1
#   2       1000      1000      0.1     0.1     1
#   3       1000      1         0.1     0.1     1
#   4       1000      1000      0.1     1e-3    1
#   5       1000      1000      0.1     0.1     10
#========================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-0}
option=$2
Mexp=${3:-5}

M0=$(perl -e 'print 10**(-'$Mexp')')
res=16
dt=0.4
end_frame=25
steps=100

CMD="$basedir/chns -test 20 -spf $steps -res $res -frame_dt $dt -e $end_frame -second_order -st_type 2 -ch_h_tol 1e-12 -mu_tol 1e-12 -p_tol 1e-12 $option "

sigma="1e-12"
mu0=0
mu1=0
rho0=1000
rho1=1000

if [ $test -eq 1 ] 
then
    sigma=1
    mu0=0
    mu1=0
    rho0=1000
    rho1=1000
elif [ $test -eq 2 ] 
then
    sigma=1
    mu0=0.1
    mu1=0.1
    rho0=1000
    rho1=1000
elif [ $test -eq 3 ] 
then
    sigma=1
    mu0=0.1
    mu1=0.1
    rho0=1
    rho1=1000
elif [ $test -eq 4 ] 
then
    sigma=1
    mu0=0.0001
    mu1=0.1
    rho0=1000
    rho1=1000
elif [ $test -eq 5 ] 
then
    sigma=10
    mu0=0.1
    mu1=0.1
    rho0=1000
    rho1=1000
fi

for refine in 1 2 4 8 16; do
# for refine in 4; do
    eta0=$(perl -e 'print 1/32')
    h=$(perl -e 'print 1/('$res'*'$refine')')
    h0=$(perl -e 'print 1/32')
    Xeta=$(perl -e 'print 2/3')
    XM=$(perl -e 'print 3/2')
    eta=0.02
    M=1e-6
    echo  $CMD -mu0 $mu0 -mu1 $mu1 -ch_sigma $sigma -ch_M $M -ch_eta $eta -rho0 $rho0 -rho1 $rho1 -range_max "1 1" -refine $refine -o $fig/steady_drop_"$test"_constant-$refine &
    $CMD -mu0 $mu0 -mu1 $mu1 -ch_sigma $sigma -ch_M $M -ch_eta $eta -rho0 $rho0 -rho1 $rho1 -range_max "1 1" -refine $refine -o $fig/steady_drop_"$test"_constant-$refine >/dev/null &
done

for refine in 1 2 4 8 16; do
# for refine in 4; do
    eta0=$(perl -e 'print 1/32')
    h=$(perl -e 'print 1/('$res'*'$refine')')
    h0=$(perl -e 'print 1/32')
    Xeta=$(perl -e 'print 2/3')
    XM=$(perl -e 'print 3/2')
    eta=$(perl -e 'print '$eta0'*('$h'/'$h0')**'$Xeta)
    M=$(perl -e 'print '$M0'*('$eta'/'$eta0')**'$XM)
    echo  $CMD -mu0 $mu0 -mu1 $mu1 -ch_sigma $sigma -ch_M $M -ch_eta $eta -rho0 $rho0 -rho1 $rho1 -range_max "1 1" -refine $refine -o $fig/steady_drop_$test-$refine &
    $CMD -mu0 $mu0 -mu1 $mu1 -ch_sigma $sigma -ch_M $M -ch_eta $eta -rho0 $rho0 -rho1 $rho1 -range_max "1 1" -refine $refine -o $fig/steady_drop_$test-$refine >/dev/null &
done

wait
