#! /usr/bin/env bash
#=================================================================
# Usage: varying_r_test.sh <fig>
#=================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-1}
end_frame=${2:-1}
option=$3
code_in=$4
sigma=0.00942809 # chosen such that lambda=1e-3
dt=0.01
use_out="-suppress_output"

rm -f $fig/tmp-*txt

CMD="$basedir/chns -test 1 -ch_M 0.001 -ch_sigma $sigma -rho0 1 -rho1 3 -mu0 0.01 -mu1 0.02 -ch_eta 0.1 -source_sym -test_sym -second_order $use_out $option -ch_h_tol 1e-15 -p_tol 1e-15 -mu_tol 1e-15 -st_type 5 -div_free -ch_optimizer -res 8 -frame_dt $dt -refine 16 -spf 1 -e $end_frame "
if [ $test -eq 1 ]
then
    if [ -z "$code_in" ]
    then
        CODE="gamma=1/2+cos(x)*cos(y)*(1-sin(t))/2.1;u=sin(x)*cos(y)*cos(t);v=-cos(x)*sin(y)*cos(t);p=cos(x)*cos(y)*sin(t);"
    else
        CODE="$code_in"
    fi
elif [ $test -eq 2 ]
then
    if [ -z "$code_in" ]
    then
        CODE="gamma=(1-r)*(1+cos(x/2+pi/2)*cos(y/2+pi/2))/2+r/2;u=sin(x)*cos(y)*cos(t);v=-cos(x)*sin(y)*cos(t);p=cos(x)*cos(y)*sin(t);"
    else
        CODE="$code_in"
    fi
fi
directory=$fig/"r_nonperiodic_test_"$test"_"$end_frame"_opt"

mkdir $directory
echo "testing varying r"
for r in 4e-1 3e-1 2e-1 1e-1 1e-2 1e-3 1e-4 1e-5 1e-6; do
    echo $CMD -gravity_v "\"1 -2\"" -o $fig/varying_r_outputs/test"$test"_$r -code "\"""$CODE""\"" -ch_min "$r"
    ( $CMD -gravity_v "1 -2" -o $fig/varying_r_outputs/test"$test"_$r -code "$CODE" -ch_min "$r" | grep "gamma2" | tail -n 1 > $directory/log_"$test"_"$r".txt) > /dev/null 2> $directory/error_"$test"_"$r".txt &
done
wait

# output table for figure generation
rm $directory/r_error_table.txt
# echo r l2err linferr  >> $directory/r_error_table.txt
for r in 4e-1 3e-1 2e-1 1e-1 1e-2 1e-3 1e-4 1e-5 1e-6; do
    l2err=$(cat $directory/log_"$test"_"$r".txt | awk '{print $8}')
    linferr=$(cat $directory/log_"$test"_"$r".txt | awk '{print $12}')
    # echo $directory/log_"$test"_"$r".txt
    # echo "$r" "$l2err" "$linferr"
    echo "$r" "$l2err" "$linferr"  >> $directory/r_error_table.txt
done
echo "logging table to $directory/r_error_table.txt"
