##! /usr/bin/env bash

basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$basedir/Figures/simp"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs

option=$1
# subtitle=$2

# Manufactured Solution Tests
(
    echo "Running Manufactured Solution Tests..."
    ($ex/paper_tests_non_periodic_ch.sh $fig 1 100 "$option" "") > $fig/logs/ch_ms.txt 2>&1 &
    ($ex/paper_tests_non_periodic.sh $fig 1 100 "$option" "") > $fig/logs/chns_ms.txt 2>&1 &
    wait
    echo "Finished Manufactured Solution Tests!"
) &

# Binary Separation Test
(
    echo "Running Binary Separation Test..."
    (($ex/ch_evolution_test.sh $fig 1 "$option -ch_b_tol 5e-7 -no_require_convergence") > $fig/logs/bs.txt 2>&1) && ($sc/separationsnapshot.sh $fig > $fig/logs/bs_script.txt 2>&1)
    echo "Finished Binary Separation Test!"
) &

# Stability Test
(
    echo "Running Stability Test..."
    ( ./example_scripts/linearized_stability_analytic.sh $fig >& $fig/logs/lin_stab.txt ) &
    ( ./example_scripts/nonlinear_stability_analytic.sh $fig >& $fig/logs/nonlin_stab.txt ) &
    wait
    echo "Finished Stability Test!"
) &

# Periodic Advection Tests
(
    echo "Running Periodic Advection Tests..."
    (for CASE in 0 1 2 3 4 5 6 7; do
         $ex/periodic_advection_test.sh $fig $CASE 0 "$option -ch_b_tol 1e-8" > $fig/logs/periodic_$CASE.txt 2>&1 &
     done
     wait ) && $sc/advection_test.sh $fig > $fig/logs/periodic_script.txt 2>&1
    echo "Finished Periodic Advection Tests!"
) &

# Steady Drop Tests
(
    echo "Running Steady Drop Tests..."
    (for CASE in 1 2 3 4 5; do
         $ex/steady_drop.sh $fig $CASE "$option -ch_b_tol 5e-8" > $fig/logs/steady_$CASE.txt 2>&1 &
     done
     wait ) && $sc/steady_error.sh $fig > $fig/logs/steady_script.txt 2>&1
    echo "Finished Steady Drop Tests!"
) &

# Surface Tension Tests
(
    echo "Running Surface Tension Tests..."
    (for CASE in 1 2 3 4 5 6 7 8 9; do
         $ex/surface_tension_tests.sh $fig $CASE "$option -ch_b_tol 1e-8" > $fig/logs/surface_tension_$CASE.txt 2>&1 &
     done
     wait ) && $sc/stgraph.sh $fig > $fig/logs/st_script.txt 2>&1
    
    echo "Finished Surface Tension Tests!"
) &

# ( (for CASE in 1 2 3 4 5 6 7 8 9; do $ex/surface_tension_tests.sh $fig $CASE > $fig/logs/surface_tension_$CASE.txt & done wait ) && $sc/stgraph.sh $fig > $fig/logs/st_script.txt) &

# Pressure and Surface Tension Tests
(
    echo "Running Pressure Tests..."
    (for CASE in 1 2 3 4 5 6 7 8 9; do
         $ex/pressure_tests.sh $fig $CASE "$option -ch_b_tol 5e-9" > $fig/logs/pressure_$CASE.txt 2>&1 &
     done
     wait ) && $sc/pressuregraph.sh $fig > $fig/logs/pressure_script.txt 2>&1
    echo "Finished Pressure Tests!."
) &

# Air Bubble Tests and Plots
(
    echo "Running Rising Bubble Tests..."
    $ex/air_bubble_test.sh $fig 0 "$option -ch_b_tol 5e-6" > $fig/logs/air_bubble.txt && $sc/air_bubble_graph.sh $fig > $fig/logs/sim2fig.txt && $sc/air_bubble_table.sh $fig > $fig/logs/air_bubble_table.txt 2>&1 
    echo "Finished Rising Bubble Tests!"
) &

# Horizontal Shear
(
    echo "Running Horizontal Shear Tests..."
    # ( (for CASE in 1 2 3 4 5 6; do
    (for CASE in 1 2 3 4; do
         $ex/horizontal_shear.sh $fig $CASE 0 "$option" > $fig/logs/shear_$CASE.txt 2>&1 &
     done
     wait ) && $sc/sheargraph.sh $fig > $fig/logs/shear_script.txt 2>&1 && $sc/shearsnapshot.sh $fig > $fig/logs/shear_script2.txt 2>&1 
    echo "Finished Horizontal Shear Tests!"
) &

# Rayleigh-Taylor
(
    echo "Running Rayleigh-Taylor Test..."
    ( for CASE in 0 1 2 3; do
          $ex/rayleigh-taylor_test.sh $fig $CASE "$option -ch_b_tol 5e-9" > $fig/logs/rayleigh-taylor_$CASE.txt 2>&1 &
      done
      wait ) && $sc/rt_surface_snapshot.sh $fig > $fig/logs/rt_snapshot_script.txt 2>&1 
    echo "Finished Rayleigh-Taylor Test!"
) &

# Dam Break
(
    echo "Running Dam Break Test..."
    $ex/dam_break_test.sh $fig 0 "$option -ch_b_tol 5e-8" > $fig/logs/dam_break.txt 2>&1 && $sc/db_surface_snapshot.sh $fig > $fig/logs/db_snapshot_script.txt 2>&1
    echo "Finished Dam Break Test!"
) &

# Equilibrium Drop
(
    echo "Running Equilibrium Drop Test..."
    ( for CASE in 0 1 2 3 4; do
          $ex/equilibrium_drop.sh $fig $CASE "$option -ch_b_tol 1e-8" > $fig/logs/equilibrium_$CASE.txt 2>&1 &
      done
      wait ) && $sc/ed_surface_snapshot.sh $fig > $fig/logs/ed_snapshot_script.txt 2>&1 
    echo "Finished Equilibrium Drop Test!"
) &

# (
# echo "Running Droplet Test..."
# $ex/droplet_test.sh $fig 0 "$option -ch_b_tol 1e-7" > $fig/logs/droplet.txt 2>&1
# echo "Finished Droplet Test!"
# ) &
# wait

wait


