##! /usr/bin/env bash

option=$1
# subtitle=$2
basedir="$PROJ/chns_project"
fig="$basedir/Figures/opt"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs

# Manufactured Solution Tests
(
    echo "Running Manufactured Solution Tests..."
    for CASE in 0 2 3; do
        $ex/paper_tests_non_periodic_ch.sh $fig $CASE 100 "$option" "" > $fig/logs/ch_ms_$CASE.txt &
    done
    wait
    $ex/generate_table_ch_triple.py $fig/refine_nonperiodic_ch_0_100_opt/gamma2_summary.txt $fig/refine_nonperiodic_ch_2_100_opt/gamma2_summary.txt $fig/refine_nonperiodic_ch_3_100_opt/gamma2_summary.txt > $fig/refine_nonperiodic_ch_triple_table.tex && cp $fig/refine_nonperiodic_ch_triple_table.tex $fig > $fig/logs/ch_ms.txt
    
    ($ex/paper_tests_non_periodic.sh $fig 0 100 "$option" "" $fig ) > $fig/logs/chns_ms.txt 2>&1 &
    wait
    echo "Finished Manufactured Solution Tests!"
) &

# Binary Separation Test
(
    echo "Running Binary Separation Test..."
    (($ex/ch_evolution_test.sh $fig 1 "$option -ch_optimizer -ch_q 0.5 -ch_n_obj_err 1e-9") > $fig/logs/bs.txt 2>&1) && ($sc/separationsnapshot.sh $fig > $fig/logs/bs_script.txt 2>&1)
    echo "Finished Binary Separation Test!"
) &

# Periodic Advection Tests
(
    echo "Running Periodic Advection Tests..."
    (for CASE in 0 1 2 3 4 5 6 7; do
         $ex/periodic_advection_test.sh $fig $CASE 1 "$option " > $fig/logs/periodic_$CASE.txt 2>&1 &
     done
     wait ) && $sc/advection_test.sh $fig > $fig/logs/periodic_script.txt 2>&1
    echo "Finished Periodic Advection Tests!"
) &

# Steady Drop Tests
(
    echo "Running Steady Drop Tests..."
    (for CASE in 1 2 3 4 5; do
         $ex/steady_drop.sh $fig $CASE "$option -ch_optimizer" > $fig/logs/steady_$CASE.txt 2>&1 &
     done
     wait ) && $sc/steady_error.sh $fig > $fig/logs/steady_script.txt 2>&1
    echo "Finished Steady Drop Tests!"
) &

# Air Bubble Tests and Plots
(
    echo "Running Rising Bubble Tests..."
    $ex/air_bubble_test.sh $fig 0 "$option -ch_optimizer" > $fig/logs/air_bubble.txt && $sc/air_bubble_graph.sh $fig 0.01 > $fig/logs/sim2fig.txt && $sc/air_bubble_table.sh $fig 0.01 > $fig/logs/air_bubble_table.txt 2>&1 
    echo "Finished Rising Bubble Tests!"
) &

# Horizontal Shear
(
    echo "Running Horizontal Shear Tests..."
    # ( (for CASE in 1 2 3 4 5 6; do
    (for CASE in 1 2 3 4; do
         $ex/horizontal_shear.sh $fig $CASE 1 "$option -ch_n_obj_err 1e-8" > $fig/logs/shear_$CASE.txt 2>&1 &
     done
     wait ) && $sc/sheargraph.sh $fig > $fig/logs/shear_script.txt 2>&1 && $sc/shearsnapshot.sh $fig > $fig/logs/shear_script2.txt 2>&1 
    echo "Finished Horizontal Shear Tests!"
) &

# Rayleigh-Taylor
(
    echo "Running Rayleigh-Taylor Test..."
    ( for CASE in 0 1 2 3; do
          $ex/rayleigh-taylor_test.sh $fig $CASE "$option -ch_optimizer -ch_n_obj_err 1e-9" > $fig/logs/rayleigh-taylor_$CASE.txt 2>&1 &
      done
      wait ) && $sc/rt_surface_snapshot.sh $fig > $fig/logs/rt_snapshot_script.txt 2>&1 
    echo "Finished Rayleigh-Taylor Test!"
) &

# Dam Break
(
    echo "Running Dam Break Test..."
    $ex/dam_break_test_short.sh $fig 0 "$option -ch_optimizer -ch_q 0.5 -ch_min 1e-4" > $fig/logs/dam_break.txt 2>&1 && $sc/db_surface_snapshot.sh $fig > $fig/logs/db_snapshot_script.txt 2>&1
    echo "Finished Dam Break Test!"
) &

wait

# Manufactured q test
(
    echo "Running Manufactured q Test..."
    $ex/constant_q_test.sh $fig 100 "$option -ch_n_obj_err 1e-7" > $fig/logs/ch_q.txt 2>&1 && $sc/q_error.py $fig > $fig/q_error.tex
    echo "Finished Manufactured q Test!"
) &

# Manufactured r test
(
    echo "Running Manufactured r Test..."
    for CASE in 2 2; do
        $ex/varying_r_test.sh $fig $CASE 100 "$option" > $fig/logs/ch_r-$CASE.txt 2>&1 && $sc/r_error.py $fig $CASE 100  > $fig/r_error_"$CASE".tex &
    done
    echo "Finished Manufactured r Test!"
) &

wait
