//##############################################################################
// MARCH2023-Mehrnaz Ayazi
//##############################################################################
#include <Core/Arrays/ARRAY.h>
#include <Core/Arrays/FACE_ARRAYS.h>
#include <Core/Grids/GRID.h>
#include <Core/Grids_Uniform_Computations/MARCHING_CUBES.h>
#include <Core/Images/TEX_FILE.h>
#include <Core/Interpolation/AVERAGING_UNIFORM.h>
#include <Core/Math_Tools/RANGE.h>
#include <Core/Math_Tools/RANGE_ITERATOR.h>
#include <Core/Meshes/MESH_OBJECT.h>
#include <Core/Meshes/SEGMENTED_CURVE.h>
#include <Core/Parsing/PARSE_ARGS.h>
#include <Core/Read_Write/FILE_UTILITIES.h>
#include <Core/Utilities/PROCESS_UTILITIES.h>
#include <Core/Utilities/VIEWER_DIR.h>


using namespace PhysBAM;

typedef double T;
typedef VECTOR<T,2> TV;
typedef VECTOR<int,2> IV;
typedef VECTOR<T,3> COLOR;

ARRAY<COLOR> colors;
std::string fig_dir;
ARRAY<std::string> dir;
ARRAY<T> dt;
ARRAY<T> sl;
ARRAY<int> end_frame;
bool cycle=false;
bool rt=false;
T rho0=0,rho1=1;
std::string fill_color="white";
//#####################################################################
// Function Search_Replace
//#####################################################################
void Search_Replace(std::string file_name,std::string new_file_name,std::string old_word,std::string new_word)
{
    std::ifstream fin(file_name);
    // Check if the file was opened successfully
    if (!fin)
    {
        std::cerr << "Error opening file" << std::endl;
        return;
    }
    // Read the contents of the file into a string
    std::string text(
            (std::istreambuf_iterator<char>(fin)),
            std::istreambuf_iterator<char>());
    fin.close();
    // Perform the search and replace operation on the string
    std::string search=old_word;
    std::string replace=new_word;
    size_t pos=0;
    while ((pos=text.find(search,pos))!=std::string::npos)
    {
        text.replace(pos,search.length(),replace);
        pos += replace.length();
    }
    // Open the file for writing
    std::ofstream fout(new_file_name,std::ios::trunc);
    // Check if the file was opened successfully
    if (!fout)
    {
        std::cerr<<"Error opening file"<<std::endl;
        return;
    }
    // Write the modified string back to the file
    fout<<text;
    fout.close();
}
//#####################################################################
// Function Dump_Surface_data
//#####################################################################
void Dump_Surface_data(const std::string& file)
{
    for(int i=0;i<dir.m;i++)
    {
        VIEWER_DIR viewer_dir(fig_dir+"/"+dir(i));
        int j=0;
        viewer_dir.Set(0);
        GRID<TV> grid;
        Read_From_File(viewer_dir.Common_File("grid"),grid);
        LOG::cout<<"the end frame is"<<end_frame(i)<<std::endl;
        for(;viewer_dir.Valid_Frame(false) and (end_frame(i)==-1?true:j<=end_frame(i));viewer_dir.Set(j))
        {
            LOG::cout<<"taking snapshot of frame ="<<j<<std::endl;
            std::ofstream stream(fig_dir+"/txt/"+dir(i)+"_"+std::to_string(j)+"_"+file);
            LOG::fprintf(stream,"x y\n");

            ARRAY<T,IV> gamma;
            Read_From_File(viewer_dir.Frame_File("display_gamma"),gamma);
            //create surface and add to text file
            MESH_OBJECT<TV,TV::m-1> surface;
            T contour_value=(T)0.5;
            MARCHING_CUBES<TV>::Create_Surface(surface,grid,at_cells,gamma,contour_value);
            surface.mesh.Initialize_Ordered_Components();
            int component_id=0;
            std::string addplot="";
            //Line segments data and plot
            for(const auto &l:*surface.mesh.connected_segments)
            {
//                LOG::cout<<"creating file: "<<fig_dir+"/txt/"+dir(i)+"_"+std::to_string(j)+"_"+std::to_string(component_id)+"-"+file<<std::endl;
                std::ofstream component_stream(fig_dir+"/txt/"+dir(i)+"_"+std::to_string(j)+"_"+std::to_string(component_id)+"-"+file);
                LOG::fprintf(component_stream,"x y\n");
                ARRAY<TV> pts(surface.particles.X.Subset(l));
                //writing the surface data to a file
                for(int j=0;j<pts.Size();++j)
                    LOG::fprintf(component_stream,"%p %p\n",pts(j)(0),pts(j)(1));

                //Adding the segment plot to tex file
                addplot+="\\addplot+[smooth][mark=none,smooth,color=black,fill="+fill_color+"] table[x=x,y=y]{"+fig_dir+"/txt/"+dir(i)+"_"+std::to_string(j)+"_"+std::to_string(component_id)+"-"+file+"}\\closedcycle;\n";
                component_id++;
            }
            //loops data and plot
            for(const auto &l:*surface.mesh.ordered_loop_nodes)
            {
                std::ofstream component_stream(fig_dir+"/txt/"+dir(i)+"_"+std::to_string(j)+"_"+std::to_string(component_id)+"-"+file);
                LOG::fprintf(component_stream,"x y\n");
                ARRAY<TV> pts(surface.particles.X.Subset(l));
                for(int j=0;j<pts.Size();++j)
                    LOG::fprintf(component_stream,"%p %p\n",pts(j)(0),pts(j)(1));

                addplot+="\\addplot+[smooth][mark=none,smooth,color=black,fill="+fill_color+"] table[x=x,y=y]{"+fig_dir+"/txt/"+dir(i)+"_"+std::to_string(j)+"_"+std::to_string(component_id)+"-"+file+"}--cycle;\n";
                component_id++;
            }
            Search_Replace(fig_dir+"/tex/surface_snapshot.tex",fig_dir+"/tex/surface_snapshot_"+dir(i)+"_"+std::to_string(j)+".tex","%SURFACE_SNAPSHOT_PLOTS",addplot);
            j+=sl(i);
        }
    }
}
//#####################################################################
// Function Find_max_min_rt
//#####################################################################
void Find_max_min_rt(const std::string& file)
{
    LOG::cout<<"creating min max plot for Rayleigh-Taylor"<<std::endl;
    for(int i=0;i<dir.m;i++)
    {
        std::ofstream minstream(fig_dir+"/txt/"+dir(i)+"_"+"min_"+file);
        std::ofstream maxstream(fig_dir+"/txt/"+dir(i)+"_"+"max_"+file);
        LOG::fprintf(minstream,"t y\n");
        LOG::fprintf(maxstream,"t y\n");

        VIEWER_DIR viewer_dir(fig_dir+"/"+dir(i));
        GRID<TV> grid;
        Read_From_File(viewer_dir.Common_File("grid"),grid);

        viewer_dir.Set(0);

        for(T t=(T)0;viewer_dir.Valid_Frame(false) and t*dt(i)<(T)2.7;viewer_dir.Set(t),t++)
        {
            ARRAY<T,IV> gamma;
            Read_From_File(viewer_dir.Frame_File("display_gamma"),gamma);
            //create surface and add to text file
            MESH_OBJECT<TV,TV::m-1> surface;
            T contour_value=(T)0.5;
            MARCHING_CUBES<TV>::Create_Surface(surface,grid,at_cells,gamma,contour_value);
            surface.mesh.Initialize_Ordered_Components();
            surface.Update_Bounding_Box();
            TV max = surface.bounding_box->Maximum_Corner();
            TV min = surface.bounding_box->Minimum_Corner();
            LOG::fprintf(minstream,"%p %p\n",t*dt(i),min(1));
            LOG::fprintf(maxstream,"%p %p\n",t*dt(i),max(1));
        }
    }
}
//#####################################################################
// Function Find_max_min_db
//#####################################################################
void Find_max_min_db(const std::string& file)
{
    LOG::cout<<"Fining maximum coordinates in dam break"<<std::endl;
    for(int i=0;i<dir.m;i++)
    {
        std::ofstream max_xstream(fig_dir+"/txt/"+dir(i)+"_"+"max_x_"+file);
        std::ofstream max_ystream(fig_dir+"/txt/"+dir(i)+"_"+"max_y_"+file);
        LOG::fprintf(max_xstream,"t x\n");
        LOG::fprintf(max_ystream,"t y\n");

        VIEWER_DIR viewer_dir(fig_dir+"/"+dir(i));
        GRID<TV> grid;
        Read_From_File(viewer_dir.Common_File("grid"),grid);

        viewer_dir.Set(0);

        for(T t=(T)0;viewer_dir.Valid_Frame(false) and t*dt(i)/0.0763651<(T)2.7;viewer_dir.Set(t),t++)
        {
            ARRAY<T,IV> gamma;
            Read_From_File(viewer_dir.Frame_File("display_gamma"),gamma);
            //create surface and add to text file
            MESH_OBJECT<TV,TV::m-1> surface;
            T contour_value=(T)0.5;
            MARCHING_CUBES<TV>::Create_Surface(surface,grid,at_cells,gamma,contour_value);
            surface.mesh.Initialize_Ordered_Components();
            surface.Update_Bounding_Box();
            TV max = surface.bounding_box->Maximum_Corner();
            LOG::fprintf(max_xstream,"%p %p\n",t*dt(i)/0.0763651,max(0)/0.05715);
            LOG::fprintf(max_ystream,"%p %p\n",t*dt(i)/0.0763651,max(1)/0.05715);
        }
    }
}
//#####################################################################
// Function main
//#####################################################################
int main(int argc,char *argv[])
{
    dt.Fill(1/24);
    end_frame.Fill(-1);
    PROCESS_UTILITIES::Set_Floating_Point_Exception_Handling(true);
    PROCESS_UTILITIES::Set_Backtrace(true);

    PARSE_ARGS parse_args(argc,argv);
    LOG::Initialize_Logging(false,false,1<<30,true);
    LOG::cout<<parse_args.Print_Arguments()<<std::endl;

    VECTOR<T,2> range_scale={0,1};
    std::string boundary_file="";

    parse_args.Add("-ob",&boundary_file,"string-file name","file name for data");
    parse_args.Add("-i",&dir,"string-directory name","directory name to read data from");
    parse_args.Add("-dt",&dt,"scalar-array","frame_dt");
    parse_args.Add("-sl",&sl,"scalar-array","step length");
    parse_args.Add("-e",&end_frame,"scalar-array","last frmae to snapshot");
    parse_args.Add("-fill",&fill_color,"scalar","fill color of curves");
    parse_args.Add("-rt",&rt,"is Rayleigh-Taylor snapshot");
    parse_args.Add("-fig",&fig_dir,"dir","base figure directory");

    parse_args.Parse();

    std::string boundary_file_text=boundary_file+".txt";
    Dump_Surface_data("surface_"+boundary_file_text);
    if(rt)
        Find_max_min_rt(boundary_file_text);
    else
        Find_max_min_db(boundary_file_text);
    LOG::Finish_Logging();
    return 0;
}
